==========================================
Pimydoc : insert and update chunks of text
==========================================
Pimydoc by suizokukan (suizokukan AT orange DOT fr)

A (Python3/GPLv3/OSX-Linux-Windows/CLI) project, using no additional modules
than the ones installed with Python3.

Note : this Python3 project can't be used with python2.

project's purpose
=================

Pimydoc inserts in source files the text paragraphs stored in "pimydoc", the
documentation source file. Moreover, the script updates the text paragraphs
already present in the source files if the documentation source file has
changed.

installation
============
$pip3 install pimydoc

Since pimydoc.py is a stand-alone file, you can download pimydoc.py in the target directory and use it directly :
$wget https://raw.githubusercontent.com/suizokukan/pimydoc/master/pimydoc.py

name
====
Pimydoc : [P]lease [i]nsert my doc[umentation]

more
====
see README.md file (especially the "workflow" section)
see https://github.com/suizokukan/pimydoc
